@@ -1,7 +1,7 @@
 package Perinci::Examples::CSV;
 
-our $DATE = '2017-01-12'; # DATE
-our $VERSION = '0.79'; # VERSION
+our $DATE = '2017-07-11'; # DATE
+our $VERSION = '0.80'; # VERSION
 
 use 5.010;
 use strict;
@@ -43,14 +43,18 @@ Perinci::Examples::CSV - Test CSV output
 
 =head1 VERSION
 
-This document describes version 0.79 of Perinci::Examples::CSV (from Perl distribution Perinci-Examples), released on 2017-01-12.
+This document describes version 0.80 of Perinci::Examples::CSV (from Perl distribution Perinci-Examples), released on 2017-07-11.
 
 =head1 DESCRIPTION
 
 =head1 FUNCTIONS
 
 
-=head2 output_table() -> [status, msg, result, meta]
+=head2 output_table
+
+Usage:
+
+ output_table() -> [status, msg, result, meta]
 
 Output some table, try displaying it on CLI with --format=csv.
 
@@ -91,7 +95,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
