@@ -1,7 +1,7 @@
 package Perinci::Examples::SubMeta;
 
-our $DATE = '2017-01-12'; # DATE
-our $VERSION = '0.79'; # VERSION
+our $DATE = '2017-07-11'; # DATE
+our $VERSION = '0.80'; # VERSION
 
 use 5.010;
 use strict;
@@ -167,7 +167,7 @@ Perinci::Examples::SubMeta - Test argument submetadata
 
 =head1 VERSION
 
-This document describes version 0.79 of Perinci::Examples::SubMeta (from Perl distribution Perinci-Examples), released on 2017-01-12.
+This document describes version 0.80 of Perinci::Examples::SubMeta (from Perl distribution Perinci-Examples), released on 2017-07-11.
 
 =head1 DESCRIPTION
 
@@ -184,7 +184,11 @@ property is another Rinci function metadata.
 =head1 FUNCTIONS
 
 
-=head2 register_donors(%args) -> [status, msg, result, meta]
+=head2 register_donors
+
+Usage:
+
+ register_donors(%args) -> [status, msg, result, meta]
 
 Register donor(s).
 
@@ -228,7 +232,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 register_student(%args) -> [status, msg, result, meta]
+=head2 register_student
+
+Usage:
+
+ register_student(%args) -> [status, msg, result, meta]
 
 Register a student to a class.
 
@@ -287,7 +295,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
