@@ -1,7 +1,7 @@
 package Perinci::Examples::Table;
 
-our $DATE = '2017-01-12'; # DATE
-our $VERSION = '0.79'; # VERSION
+our $DATE = '2017-07-11'; # DATE
+our $VERSION = '0.80'; # VERSION
 
 use 5.010;
 use strict;
@@ -66,7 +66,7 @@ Perinci::Examples::Table - Table examples
 
 =head1 VERSION
 
-This document describes version 0.79 of Perinci::Examples::Table (from Perl distribution Perinci-Examples), released on 2017-01-12.
+This document describes version 0.80 of Perinci::Examples::Table (from Perl distribution Perinci-Examples), released on 2017-07-11.
 
 =head1 DESCRIPTION
 
@@ -75,7 +75,11 @@ The examples in this module return table data.
 =head1 FUNCTIONS
 
 
-=head2 aoaos() -> [status, msg, result, meta]
+=head2 aoaos
+
+Usage:
+
+ aoaos() -> [status, msg, result, meta]
 
 Return an array of array-of-scalar (aoaos) data.
 
@@ -95,7 +99,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 aohos() -> [status, msg, result, meta]
+=head2 aohos
+
+Usage:
+
+ aohos() -> [status, msg, result, meta]
 
 Return an array of hash-of-scalar (aohos) data.
 
@@ -136,7 +144,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
