@@ -1,7 +1,7 @@
 package Perinci::Examples::Tiny::Result;
 
-our $DATE = '2017-01-12'; # DATE
-our $VERSION = '0.79'; # VERSION
+our $DATE = '2017-07-11'; # DATE
+our $VERSION = '0.80'; # VERSION
 
 our %SPEC;
 
@@ -54,7 +54,7 @@ Perinci::Examples::Tiny::Result - Tests related to function result
 
 =head1 VERSION
 
-This document describes version 0.79 of Perinci::Examples::Tiny::Result (from Perl distribution Perinci-Examples), released on 2017-01-12.
+This document describes version 0.80 of Perinci::Examples::Tiny::Result (from Perl distribution Perinci-Examples), released on 2017-07-11.
 
 =head1 DESCRIPTION
 
@@ -65,7 +65,11 @@ Perinci::CmdLine frameworks.
 =head1 FUNCTIONS
 
 
-=head2 returns_circular() -> [status, msg, result, meta]
+=head2 returns_circular
+
+Usage:
+
+ returns_circular() -> [status, msg, result, meta]
 
 This function returns circular structure.
 
@@ -87,7 +91,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 returns_scalar_ref() -> [status, msg, result, meta]
+=head2 returns_scalar_ref
+
+Usage:
+
+ returns_scalar_ref() -> [status, msg, result, meta]
 
 This function returns a scalar reference.
 
@@ -130,7 +138,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
